@@ -100,8 +100,7 @@ class NVD3Chart:
     show_legend = True
     show_labels = True
 
-    def __init__(self, name=None, color_category=None, jquery_on_ready=False,
-                 **kwargs):
+    def __init__(self, **kwargs):
         """
         Constructor
         """
@@ -115,24 +114,14 @@ class NVD3Chart:
         self.template_content_nvd3 = Template(template_content_nvd3)
         self.charttooltip_dateformat = '%d %b %Y'
 
-        if not name:
-            self.count += 1
-            name = "chart%d" % (self.count)
-        self.name = name
-
-        self.jquery_on_ready = jquery_on_ready
-
-        if color_category:
-            self.color_category = color_category
-
-        if 'stacked' in kwargs and kwargs["stacked"]:
-            self.stacked = True
-
-        if 'resize' in kwargs and kwargs["resize"]:
-            self.resize = True
-
+        self.name = kwargs.get('name', self.model)
+        self.jquery_on_ready = kwargs.get('jquery_on_ready', False)
+        self.color_category = kwargs.get('color_category', None)
+        self.stacked = kwargs.get('stacked', False)
+        self.resize = kwargs.get('resize', False)
         self.show_legend = kwargs.get("show_legend", True)
         self.show_labels = kwargs.get("show_labels", True)
+        self.tag_script_js = kwargs.get("tag_script_js", True)
 
         #CDN http://cdnjs.com/libraries/nvd3/ needs to make sure it's up to date
         self.header_css = [
@@ -155,7 +144,26 @@ class NVD3Chart:
         add serie - Series are list of data that will be plotted
         y {1, 2, 3, 4, 5} / x {1, 2, 3, 4, 5}
 
-        TODO: Add doc for supported parameters, ie x_axis_date, shape, size
+        **Attributes**:
+
+            * ``name`` - set Serie name
+            * ``x`` - x-axis data
+            * ``y`` - y-axis data
+
+            kwargs:
+
+            * ``shape`` - for scatterChart, you can set different shapes (circle, triangle etc...)
+            * ``size`` - for scatterChart, you can set size of different shapes
+            * ``type`` - for multiChart, type should be bar
+            * ``bar`` - to display bars in Chart
+            * ``color_list`` - define list of colors which will be used by pieChart
+            * ``color`` - set axis color
+            * ``disabled`` -
+
+            extra:
+
+            * ``tooltip`` - set tooltip flag
+            * ``date_format`` - set date_format for tooltip if x-axis is in date format
 
         """
         if not name:
@@ -163,14 +171,9 @@ class NVD3Chart:
 
         # For scatterChart shape & size fields are added in serie
         if 'shape' in kwargs or 'size' in kwargs:
-            if 'size' in kwargs and kwargs["size"]:
-                csize = kwargs["size"]
-            else:
-                csize = 1
-            if 'shape' in kwargs and kwargs["shape"]:
-                cshape = kwargs["shape"]
-            else:
-                cshape = "circle"
+            csize = kwargs.get("size", 1)
+            cshape = kwargs.get("shape", "circle")
+
             serie = [{
                 "x": x[i],
                 "y": y,
@@ -281,7 +284,7 @@ class NVD3Chart:
         self.buildcontainer()
         self.buildjschart()
         self.htmlcontent = self.template_content_nvd3.substitute(container=self.container,
-                                              jschart=self.jschart)
+                                                                 jschart=self.jschart)
 
     def buildhtml(self):
         """Build the HTML page
@@ -293,7 +296,9 @@ class NVD3Chart:
         self.buildcontainer()
         self.buildjschart()
 
-        self.htmlcontent = self.template_page_nvd3.substitute(header=self.htmlheader, container=self.container, jschart=self.jschart)
+        self.htmlcontent = self.template_page_nvd3.substitute(header=self.htmlheader,
+                                                              container=self.container,
+                                                              jschart=self.jschart)
 
     def buildhtmlheader(self):
         """generate HTML header content"""
@@ -434,8 +439,8 @@ class NVD3Chart:
         series_js = json.dumps(self.series)
 
         if self.model == 'linePlusBarWithFocusChart':
-            append_to_data = ".map(function(series) {"+\
-                "series.values = series.values.map(function(d) { return {x: d[0], y: d[1] } });"+\
+            append_to_data = ".map(function(series) {" + \
+                "series.values = series.values.map(function(d) { return {x: d[0], y: d[1] } });" + \
                 "return series; })"
             self.jschart += """data_%s=%s%s;\n""" % (self.name, series_js, append_to_data)
         else:
@@ -497,10 +502,10 @@ def _main():
     """
     # Parse arguments
     usage = "usage: nvd3.py [options]"
-    parser = OptionParser(usage=usage, version="python-nvd3 0.2.2 - Python wrapper for nvd3 ")
+    parser = OptionParser(usage=usage, version="python-nvd3 - Charts generator with nvd3.js and d3.js")
     parser.add_option("-q", "--quiet",
-                  action="store_false", dest="verbose", default=True,
-                  help="don't print messages to stdout")
+                      action="store_false", dest="verbose", default=True,
+                      help="don't print messages to stdout")
 
     (options, args) = parser.parse_args()
 
