@@ -9,7 +9,12 @@ for d3.js without taking away the power that d3.js gives you.
 Project location : https://github.com/areski/python-nvd3
 """
 
-__version__ = '0.10.2'  # edit also docs/source/conf.py
+__version__ = '0.11.0'  # edit also docs/source/conf.py
+__all__ = ['lineChart', 'pieChart', 'lineWithFocusChart',
+           'stackedAreaChart', 'multiBarHorizontalChart',
+           'linePlusBarChart', 'cumulativeLineChart',
+           'scatterChart', 'discreteBarChart', 'multiBarChart',
+           'linePlusBarWithFocusChart']
 
 
 from .lineChart import lineChart
@@ -23,47 +28,3 @@ from .scatterChart import scatterChart
 from .discreteBarChart import discreteBarChart
 from .multiBarChart import multiBarChart
 from .linePlusBarWithFocusChart import linePlusBarWithFocusChart
-
-
-class lineChart(lineChart):
-    pass
-
-
-class pieChart(pieChart):
-    pass
-
-
-class lineWithFocusChart(lineWithFocusChart):
-    pass
-
-
-class linePlusBarWithFocusChart(linePlusBarWithFocusChart):
-    pass
-
-
-class stackedAreaChart(stackedAreaChart):
-    pass
-
-
-class multiBarHorizontalChart(multiBarHorizontalChart):
-    pass
-
-
-class linePlusBarChart(linePlusBarChart):
-    pass
-
-
-class cumulativeLineChart(cumulativeLineChart):
-    pass
-
-
-class scatterChart(scatterChart):
-    pass
-
-
-class discreteBarChart(discreteBarChart):
-    pass
-
-
-class multiBarChart(multiBarChart):
-    pass
