@@ -72,15 +72,20 @@ class multiBarChart(NVD3Chart):
             return chart;
         });
     """
-    def __init__(self, height=450, width=None, date=False, x_axis_format="%d %b %Y", **kwargs):
+    def __init__(self, **kwargs):
         NVD3Chart.__init__(self, **kwargs)
-        if date:
+        height = kwargs.get('height', 450)
+        width = kwargs.get('width', None)
+
+        if kwargs.get('x_is_date', False):
             self.set_date_flag(True)
-            self.create_x_axis('xAxis', format=x_axis_format, date=True)
+            self.create_x_axis('xAxis',
+                               format=kwargs.get('x_axis_format', '%d %b %Y'),
+                               date=True)
             self.set_custom_tooltip_flag(True)
         else:
-            self.create_x_axis('xAxis', format=".2f")
-        self.create_y_axis('yAxis', format=".2f")
+            self.create_x_axis('xAxis', format=kwargs.get('x_axis_format', '.2f'))
+        self.create_y_axis('yAxis', format=kwargs.get('y_axis_format', '.2f'))
         # must have a specified height, otherwise it superimposes both chars
         if height:
             self.set_graph_height(height)
