@@ -110,10 +110,13 @@ class scatterChart(NVD3Chart):
             return chart;
         });
     """
-    def __init__(self, height=450, width=None, **kwargs):
+    def __init__(self, **kwargs):
         NVD3Chart.__init__(self, **kwargs)
-        self.create_x_axis('xAxis', format=".02f")
-        self.create_y_axis('yAxis', format=".02f")
+        height = kwargs.get('height', 450)
+        width = kwargs.get('width', None)
+
+        self.create_x_axis('xAxis', format=kwargs.get('x_axis_format', '.02f'))
+        self.create_y_axis('yAxis', format=kwargs.get('y_axis_format', '.02f'))
         # must have a specified height, otherwise it superimposes both chars
         if height:
             self.set_graph_height(height)
